module.exports = function ( grunt ) {

    grunt.initConfig( {
        html2js: {
            options: {
                module: 'KlickFlupp.console',
                singleModule: true,
                existingModule: true
            },
            main: {
                src: [ 'src/*.html' ],
                dest: 'src/console.directive.template.js'
            }
        },
        concat: {
            options: {
                sourceMap: true,
                separator: '\n',
                banner: "(function(){\n",
                footer: "\n})();",
                process: function ( src ) {

                    return "(function(){\n" + src + "\n})();";

                }
            },
            console: {
                src: 'src/**/*.js',
                dest: 'dist/console.js'
            },
            scripts: {
                src: [
                    'node_modules/jquery/dist/jquery.js',
                    'node_modules/bootstrap/dist/js/bootstrap.js',
                    'node_modules/highlight.js/lib/highlight.js',
                    'node_modules/angular/angular.js',
                    'node_modules/angular-local-storage/dist/angular-local-storage.js',
                    'node_modules/angular-bootstrap-npm/dist/angular-bootstrap.js',
                    'node_modules/angular-highlightjs/src/angular-highlightjs.js',
                    'node_modules/ag-grid/dist/ag-grid.js'
                ],
                dest: 'example/scripts.js',
                nonull: true
            },
            app: {
                src: 'example/app/**/*.js',
                dest: 'example/app.js'
            }
        },
        uglify: {
            options: {
                sourceMap: false,
                sourceMapIncludeSources: true,
                sourceMapIn: 'example/app.js.map',
                mangle: false
            },
            scripts: {
                files: {
                    'client/scripts.js': 'example/scripts.js'
                }
            },
            app: {
                files: {
                    'client/app.js': 'example/app.js'
                }
            }
        },
        watch: {
            scripts: {
                files: 'example/app/**/*.js',
                tasks: [ 'concat' ]
            },
            configFiles: {
                files: [ 'Gruntfile.js' ],
                options: {
                    reload: true
                }
            }
        }
    } );

    grunt.loadNpmTasks( 'grunt-html2js' );
    grunt.loadNpmTasks( 'grunt-contrib-concat' );
    grunt.loadNpmTasks( 'grunt-contrib-uglify' );
    grunt.loadNpmTasks( 'grunt-contrib-watch' );

    grunt.registerTask( 'default', [ 'html2js', 'concat:console', 'concat:app' ] );
    grunt.registerTask( 'debug', [ 'html2js', 'concat' ] );
    grunt.registerTask( 'release', [ 'html2js', 'concat', 'uglify' ] );

};