var directive = function ( $templateCache, consoleGridOptionsFactory, requestService ) {

    'use strict';

    var template = $templateCache.get( 'console.directive.template.html' );

    return {
        restrict: 'E',
        replace: true,
        scope: {
            showConsole: '='
        },
        template: template,
        link: function ( scope ) {

            scope.showConsole = scope.showConsole || false;
            scope.gridOptions = consoleGridOptionsFactory();
            scope.selectedItem = null;
            scope.selected = false;
            scope.rowData = requestService.requests;

            scope.toggleAction = function () {

                scope.showConsole = scope.showConsole !== true;

                if ( !scope.$$phase ) {
                    scope.$apply();
                }

            };

            scope.clearAction = function () {

                requestService.clear();

                scope.selectedItem = null;
                scope.selected = false;

            };

            scope.$watch( 'ready', function () {

                if ( scope.ready === true && scope.gridOptions.api ) {

                    scope.gridOptions.api.addEventListener( 'rowSelected', function ( event ) {

                        scope.selectedItem = event.node.data;
                        scope.selected = true;

                    } );

                    document.onkeydown = function ( e ) {
                        var evtObj = window.event ? event : e;
                        if ( evtObj.keyCode == 67 && evtObj.ctrlKey && evtObj.altKey ) {

                            scope.toggleAction();

                        }
                    };

                }

            } );

            scope.$watch( 'rowData', function ( rowData ) {

                var gridApi = null;

                if ( rowData && scope.gridOptions.api ) {

                    gridApi = scope.gridOptions.api;
                    gridApi.setRowData( rowData );

                    if ( rowData.length > 0 ) {
                        gridApi.selectIndex( 0 );
                    }

                }

            }, true );

            scope.ready = true

        }
    };

};

angular.module( 'KlickFlupp.console' ).directive(
    'cfConsole',
    [
        '$templateCache',
        'consoleGridOptionsFactory',
        'RequestService',
        directive
    ]
);